(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     52258,       1004]
NotebookOptionsPosition[     51794,        987]
NotebookOutlinePosition[     52169,       1003]
CellTagsIndexPosition[     52126,       1000]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"speed", " ", "of", " ", "light", " ", 
    RowBox[{"m", "/", "s"}]}], "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "=", "2.998*^8"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Rydberg", " ", "Constant", " ", "in", " ", "SI"}], "*)"}], " ", 
   RowBox[{
    RowBox[{"R", "=", "10967700"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Charge", " ", "of", " ", "Electron", " ", "in", " ", "SI"}], 
    "*)"}], " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["C", "e"], "=", "1.60*^-19"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"H", "-", 
     RowBox[{"bar", " ", "SI", " ", "units"}]}], "*)"}], " ", 
   RowBox[{
    RowBox[{"H", "=", " ", "1.06*^-34"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Epsilon", " ", "naught", " ", "SI", " ", "units"}], "*)"}], 
   RowBox[{
    RowBox[{
     SubscriptBox["e", "0"], "=", "8.85*^-12"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Bohr", " ", "Radius", " ", "SI"}], "*)"}], " ", 
   RowBox[{
    RowBox[{"r", "=", "5.29*^-11"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"e", "^", "2"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"3", "*", "pi", "*", "epsilon", " ", "naught", "*", 
       RowBox[{"c", "^", "3"}]}], ")"}]}], "*)"}], 
   RowBox[{
    RowBox[{"alpha", "=", "1.14*^-53"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "mass", " ", "in", " ", "kilos", " ", "of", " ", "electron", " ", "SI"}], 
    "*)"}], " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["M", "e"], "=", "9.109383*^-31"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"l", "=", "50"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", "=", "100"}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"REMEMBER", " ", "THAT", " ", "N"}], ">", 
     RowBox[{"L", "!"}]}], "*)"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a", "=", " ", 
     SqrtBox[
      RowBox[{" ", 
       RowBox[{"1", "-", 
        FractionBox[
         RowBox[{"l", "*", 
          RowBox[{"(", 
           RowBox[{"l", "+", "1"}], ")"}]}], 
         SuperscriptBox["n", "2"]]}]}]]}], ";"}], " ", 
   RowBox[{"(*", "eccentricity", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"s", " ", "=", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"BesselJ", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1"}], "+", "k"}], ",", 
           RowBox[{"k", "*", "a"}]}], "]"}], "-", 
         RowBox[{"BesselJ", "[", 
          RowBox[{
           RowBox[{"1", "+", "k"}], ",", 
           RowBox[{"k", "*", "a"}]}], "]"}]}], ")"}]}], ")"}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"^", " ", "This"}], " ", "is", " ", "right", " ", 
      RowBox[{"eq", ".", " ", "for"}], " ", "derivative"}], ",", " ", 
     RowBox[{
      RowBox[{"check", " ", 
       RowBox[{"http", ":"}]}], "//", 
      RowBox[{
       RowBox[{
        RowBox[{"functions", ".", "wolfram", ".", "com"}], "/", "Bessel"}], 
       "-", 
       RowBox[{
        RowBox[{
         RowBox[{"TypeFunctions", "/", "BesselJ"}], "/", "20"}], "/", 
        RowBox[{"ShowAll", ".", "html"}]}]}]}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"j", " ", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["n", "2"], "*", 
       RowBox[{"(", 
        RowBox[{"4", "*", "\[Pi]", "*", 
         SubscriptBox["e", "0"]}], ")"}], "*", 
       SuperscriptBox["H", "2"]}], 
      RowBox[{
       SubscriptBox["M", "e"], "*", 
       SuperscriptBox[
        SubscriptBox["C", "e"], "2"]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"q", " ", "=", " ", 
     RowBox[{"k", "*", "a"}]}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"k", " ", "*", " ", "eccentricity"}], " ", "*)"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h", "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "-", 
           SuperscriptBox["a", "2"]}], 
          SuperscriptBox["a", "2"]], ")"}], "]"}], "*", 
       RowBox[{"(", 
        RowBox[{"BesselJ", "[", 
         RowBox[{"k", ",", 
          RowBox[{"k", "*", "a"}]}], "]"}], ")"}]}], ")"}]}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"bessel", " ", "function"}], "*)"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["n", "3"]], "*", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         SubscriptBox["M", "e"], "*", 
         SuperscriptBox[
          SubscriptBox["C", "e"], "4"]}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"4", "*", "\[Pi]", "*", 
            SubscriptBox["e", "0"]}], ")"}], "2"], "*", 
         SuperscriptBox["H", "3"]}]], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "k", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"end", " ", "=", " ", 
     FractionBox[
      RowBox[{"2", "*", "Pi"}], 
      RowBox[{"k", "*", "w"}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"2", "*", "r"}], "k"], "*", "s", "*", 
          RowBox[{"Cos", "[", 
           RowBox[{"k", "*", "w", "*", "t"}], "]"}]}], ",", 
         RowBox[{
          FractionBox[
           RowBox[{"2", "*", "r"}], "k"], "*", "h", "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"k", "*", "w", "*", "t"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "0.00001"}], "}"}]}], "]"}], ";"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"t", "[", "delta_", "]"}], ":=", " ", 
     RowBox[{
      FractionBox["n", "2"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"delta", "/", "n"}]}], ")"}], 
         RowBox[{"-", "2"}]], "-", "1"}], ")"}]}]}], " ", 
    RowBox[{"(*", 
     RowBox[{"*", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"(", 
          FractionBox["delta", "n"], ")"}]}], ")"}], 
       RowBox[{"-", "3"}]]}], "*)"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"points", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Map", "[", 
       RowBox[{"t", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "50"}], "]"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xx", " ", "=", " ", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"2", "*", "r"}], "k"], "*", "s", "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"k", "*", "w", "*", "t"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "100"}], "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"yy", " ", "=", " ", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"2", "*", "r"}], "k"], "*", "h", "*", 
        RowBox[{"Sin", "[", 
         RowBox[{"k", "*", "w", "*", "t"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "100"}], "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"xx", ",", "yy"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "0.000000001"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8019947420843344`*^9, 3.801994814279565*^9}, {
   3.80199484612988*^9, 3.801994854953268*^9}, {3.801996178406687*^9, 
   3.8019964090973177`*^9}, {3.8019964489437118`*^9, 
   3.8019964706945257`*^9}, {3.801999146049223*^9, 3.8019991836072574`*^9}, {
   3.801999246591488*^9, 3.801999443885147*^9}, {3.8020047905435467`*^9, 
   3.8020048097724004`*^9}, 3.802004885330201*^9, {3.802004915643877*^9, 
   3.8020049392885275`*^9}, {3.802005051427193*^9, 3.802005051931449*^9}, {
   3.8020052357070513`*^9, 3.80200526735401*^9}, {3.8020053161260967`*^9, 
   3.8020053164398804`*^9}, {3.8020162639599566`*^9, 3.802016277387101*^9}, {
   3.80201631674148*^9, 3.8020163181018*^9}, {3.8020163730685177`*^9, 
   3.80201645748098*^9}, {3.80201648774818*^9, 3.8020165263030014`*^9}, {
   3.802016721766386*^9, 3.802016769385683*^9}, {3.802016814621126*^9, 
   3.8020168686488867`*^9}, {3.802016902907795*^9, 3.802016907259914*^9}, {
   3.8020169802186575`*^9, 3.8020169828675556`*^9}, {3.8020174303753386`*^9, 
   3.8020174605665646`*^9}, {3.8020175102552714`*^9, 3.802017510522588*^9}, {
   3.802017590201886*^9, 3.802017592490762*^9}, {3.802017787339984*^9, 
   3.802017817743019*^9}, {3.8020180883672514`*^9, 3.8020181062715297`*^9}, {
   3.8020182646191497`*^9, 3.8020182726117983`*^9}, {3.802018359955118*^9, 
   3.8020183865103245`*^9}, {3.8020184215984497`*^9, 3.802018501663302*^9}, {
   3.802018580644943*^9, 3.802018670861204*^9}, 3.8020187377052307`*^9, {
   3.802018840167354*^9, 3.8020188826673145`*^9}, {3.802032893157151*^9, 
   3.80203313995277*^9}, {3.8020333751683187`*^9, 3.8020333977583475`*^9}, {
   3.8020800675737844`*^9, 3.8020801174723253`*^9}, {3.802080163925568*^9, 
   3.802080236551552*^9}, {3.8020802757989097`*^9, 3.802080283643219*^9}, {
   3.802081745618742*^9, 3.8020818960079694`*^9}, {3.8021060383476925`*^9, 
   3.8021060458981004`*^9}, {3.8021062810138397`*^9, 
   3.8021063242149816`*^9}, {3.802106387863988*^9, 3.802106400290573*^9}, {
   3.8021064621203003`*^9, 3.8021064984970894`*^9}},
 CellLabel->
  "In[162]:=",ExpressionUUID->"22a616c9-8077-45ae-abc0-cd00fec661bc"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwsW3c8Fd77V1REpTIyElIqW1bpKTKifKJSGRHJyCyjkFHZ2SMze+9rXNzx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       "]]},
     Annotation[#, "Charting`Private`Tag$3009#1"]& ]}, {}},
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "ScalingFunctions" -> 
    None},
  PlotRange->{{-3.007000457479622*^-11, 
   7.572664754860278*^-11}, {-2.6713126304999637`*^-11, 
   2.6713302148143247`*^-11}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.802032992485523*^9, {3.8020330236604223`*^9, 3.802033140300845*^9}, {
   3.802033376959564*^9, 3.802033398114363*^9}, 3.8020801186112385`*^9, {
   3.802080183674975*^9, 3.802080237095067*^9}, {3.8020802765479403`*^9, 
   3.802080284109973*^9}, 3.802081756897208*^9, {3.802081787705228*^9, 
   3.8020818156016273`*^9}, {3.8020818468718047`*^9, 
   3.8020819030281844`*^9}, {3.8021062955862823`*^9, 3.802106325199251*^9}, 
   3.8021064231102877`*^9, {3.8021064759922276`*^9, 3.802106499026716*^9}},
 CellLabel->
  "Out[184]=",ExpressionUUID->"91c3aed1-9b4d-4eca-b165-37cf5e0c11db"]
}, Open  ]]
},
WindowSize->{1920, 997},
WindowMargins->{{1912, Automatic}, {Automatic, -8}},
Magnification:>1.4 Inherited,
FrontEndVersion->"12.0 for Microsoft Windows (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 10135, 272, 1123, "Input",ExpressionUUID->"22a616c9-8077-45ae-abc0-cd00fec661bc"],
Cell[10718, 296, 41060, 688, 267, "Output",ExpressionUUID->"91c3aed1-9b4d-4eca-b165-37cf5e0c11db"]
}, Open  ]]
}
]
*)

